@@ -746,6 +746,10 @@ class TreasuryTx(DbEntity):
         """Human-readable label for the sender address."""
         return self.from_address.nickname or self.from_address.address  # type: ignore [union-attr]
 
+    @property
+    def token_address(self) -> ChecksumAddress:
+        return self.token.address.address
+
     @property
     def symbol(self) -> str:
         """Ticker symbol for the transferred token."""
